def edit_config_raw_file(conf_path, config_dict, base_file=None, encoding=None):
    r"""
    Edits a configuration file at the given path.
    This function allows you to edit INI files with incorrect format, flat files, dirty JSON, etc.

    Args:
        conf_path (str): The path to the configuration file.
        config_dict (dict): A dictionary containing key-value pairs to be updated or added in the configuration file.
            The key is the string at the beginning of the line you are trying to edit.
            The value is the new replacing line.
            (Note: take care of spaces and tabs (\t), but line return (\n) will be added automatically.)
        base_file (str or None, optional): The base file content to be used if the configuration file doesn't exist.
            It can be either a string representing the base content or a file path. Defaults to None.
        encoding (str, optional): The encoding of the configuration file. If not specified, the function attempts to detect it. Defaults to None.

    Returns:
        (dict or list): The dictionary with the previous line as the key and the new line as the value for edited lines. The list of written lines.

    Example:
    >>> edit_config_raw_file(user_conf_path, config_dict, encoding="UTF-8-SIG")
    {'Language=en-US\n': 'Language=fr-FR\n', 'Destinations=Picker\n': 'Destinations=Editor\n',
    'CaptureMousepointer=True\n': 'CaptureMousepointer=False\n'}
    >>> edit_config_raw_file(server_cfg_file, config_dict))
    ['UpdateFrequency 0\n']

    """
    result_dict = {}
    new_lines = []

    if not encoding and os.path.isfile(conf_path):
        encoding = detect_file_encoding(conf_path)
    else:
        encoding = "UTF-8"

    if not os.path.isfile(conf_path):
        if base_file is None:
            print(f'"{conf_path}" file does not exist, and you did not provide a base_file. Writing values of config_dict line by line.')
            new_lines = set()
            for key, value in config_dict.items():
                new_line = value + "\n"
                new_lines.add(new_line)
            new_lines = list(new_lines)
        else:
            if isfile(base_file):
                # encoding = detect_file_encoding(base_file)
                with open(conf_path, "r", encoding=encoding) as f:
                    new_lines = f.readlines()
            else:
                new_lines = base_file.splitlines()
    else:
        with open(conf_path, "r", encoding=encoding) as f:
            for line in f:
                line_edited = False
                old_line = line
                line = line.rstrip("\n")
                for key, value in config_dict.items():
                    if line.startswith(key):
                        line = value
                        line_edited = True
                        break
                new_line = line + "\n"
                new_lines.append(new_line)
            if line_edited:
                result_dict[old_line] = new_line

    with open(conf_path, "w", encoding=encoding) as f:
        f.writelines(new_lines)

    if result_dict:
        return result_dict
    else:
        return new_lines


def detect_file_encoding(file_path):
    """Detect the encoding of a file."""
    import chardet

    with open(file_path, "rb") as file:
        raw_data = file.read()
        result = chardet.detect(raw_data)
        return result["encoding"]
